@@ -20,12 +20,13 @@ from twisted.python import log as tlog
 from subprocess import Popen
 from os import path
 from dns.resolver import Resolver
-from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger
+from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars
 from uuid import uuid4
 
 
 class QDNSServer():
     def __init__(self, ip=None, port=None, resolver_addresses=None, config=''):
+        self.auto_disabled = None
         self.ip = ip or '0.0.0.0'
         self.port = port or 53
         self.resolver_addresses = resolver_addresses or [('8.8.8.8', 53)]
@@ -34,6 +35,7 @@ class QDNSServer():
         self.config = config
         if config:
             self.logs = setup_logger(self.uuid, config)
+            set_local_vars(self,config)
         else:
             self.logs = setup_logger(self.uuid, None)
         disable_logger(1, tlog)
@@ -71,7 +73,7 @@ class QDNSServer():
 
     def run_server(self, process=False, auto=False):
         if process:
-            if auto:
+            if auto and not self.auto_disabled:
                 port = get_free_port()
                 if port > 0:
                     self.port = port
