@@ -31,19 +31,37 @@ from traceback import format_exc
 from collections import Mapping
 
 
+def set_local_vars(self,config):
+    try:
+        honeypot = None
+        if config and config != '':
+            with open(config) as f:
+                config_data = load(f)
+                honeypots = config_data['honeypots']
+                honeypot = self.__class__.__name__[1:-6].lower()
+            if honeypot and honeypot in honeypots:
+                for var in honeypots[honeypot]:
+                    if var in vars(self):
+                        setattr(self, var, honeypots[honeypot][var])
+                        if var == "port":
+                            setattr(self, "auto_disabled", True)
+    except BaseException:
+        pass
+
 def get_running_servers():
     temp_list = []
     try:
-        honeypots = ['QDNSServer','QFTPServer','QHTTPProxyServer','QHTTPServer','QHTTPSServer','QIMAPServer','QMysqlServer','QPOP3Server','QPostgresServer','QRedisServer','QSMBServer','QSMTPServer','QSOCKS5Server','QSSHServer','QTelnetServer','QVNCServer']
+        honeypots = ['QDNSServer', 'QFTPServer', 'QHTTPProxyServer', 'QHTTPServer', 'QHTTPSServer', 'QIMAPServer', 'QMysqlServer', 'QPOP3Server', 'QPostgresServer', 'QRedisServer', 'QSMBServer', 'QSMTPServer', 'QSOCKS5Server', 'QSSHServer', 'QTelnetServer', 'QVNCServer']
         for process in process_iter():
             cmdline = ' '.join(process.cmdline())
-            for honeypot in honeypots: 
+            for honeypot in honeypots:
                 if '--custom' in cmdline and honeypot in cmdline:
                     temp_list.append(cmdline.split(" --custom ")[1])
     except BaseException:
         pass
     return temp_list
 
+
 def disable_logger(logger_type, object):
     if logger_type == 1:
         temp_name = path.join(gettempdir(), next(_get_candidate_names()))
