@@ -16,12 +16,13 @@ from struct import unpack
 from requests import get
 from os import path
 from subprocess import Popen
-from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger
+from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, set_local_vars
 from uuid import uuid4
 
 
 class QSOCKS5Server():
     def __init__(self, ip=None, port=None, username=None, password=None, mocking=False, config=''):
+        self.auto_disabled = None
         self.ip = ip or '0.0.0.0'
         self.port = port or 1080
         self.username = username or "test"
@@ -32,6 +33,7 @@ class QSOCKS5Server():
         self.config = config
         if config:
             self.logs = setup_logger(self.uuid, config)
+            set_local_vars(self,config)
         else:
             self.logs = setup_logger(self.uuid, None)
 
@@ -72,7 +74,7 @@ class QSOCKS5Server():
 
     def run_server(self, process=False, auto=False):
         if process:
-            if auto:
+            if auto and not self.auto_disabled:
                 port = get_free_port()
                 if port > 0:
                     self.port = port
